#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-rerun
version:              1.1.18
visibility:           public
id:                   tasty-rerun-1.1.18-AMcA8z8AQ2R4xjxGBlKsC3
key:                  tasty-rerun-1.1.18-AMcA8z8AQ2R4xjxGBlKsC3
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  7f460a344d7b5d3dd514ef333fcd5da4
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-8.10.5/site-local/tasty-rerun-1.1.18
library-dirs:         /usr/lib/ghc-8.10.5/site-local/tasty-rerun-1.1.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/tasty-rerun-1.1.18
hs-libraries:         HStasty-rerun-1.1.18-AMcA8z8AQ2R4xjxGBlKsC3
depends:
    base-4.14.2.0 containers-0.6.4.1 mtl-2.2.2
    optparse-applicative-0.16.1.0-ARX6qDeExVWDKYrQ55nL8e
    split-0.2.3.4-6NNts3pcZSB6Io5fuJ9m3X stm-2.5.0.1
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV
    tasty-1.4.1-o6GqK7uhQW6VZVrPJnWQG transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

